@@ -10,4 +10,7 @@ func (fs *FileServer) logOnly(w http.ResponseWriter, req *http.Request) {
 	logger.LogRequest(req, http.StatusOK, fs.Verbose)
 	w.WriteHeader(200)
 	w.Write([]byte("ok\n"))
+
+	// Send webhook message
+	fs.HandleWebhookSend("", "verbose")
 }
